@@ -543,6 +543,23 @@ class VacBot():
         
         self.AddMapPiece(response['pieceIndex'], response['pieceValue'])
 
+    def _handle_major_map(self, event):
+        response = event['body']['data']
+        
+        values = response['value'].split(",")
+
+        # Initialize new map Cache
+        if len(self.mapPieces) == 0:
+            for i in range(64):
+                self.mapPieces.append(str(i) + '-' + str(values[i]))
+                self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
+        else:
+            for i in range(64):
+                if self.mapPieces[i] != str(i) + '-' + str(values[i]):
+                    self.mapPieces[i] = str(i) + '-' + str(values[i])
+                    _LOGGER.debug("UPDATING MAP PIECE: " + str(i))
+                    self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
+
     def _handle_cached_map(self, event):
         response = event['body']['data']
         mapid = response['info'][0]['mid']
@@ -550,10 +567,6 @@ class VacBot():
         self.rooms = []
         self.exc_command('getMapSet', {'mid': mapid,'type': 'ar'})
 
-        for i in range(64):
-            self.exc_command('getMinorMap', {'mid': mapid,'type': 'ol', 'pieceIndex': i})
-        
-
     def _handle_map_set(self, event):
         response = event['body']['data']
         
@@ -650,7 +663,6 @@ class VacBot():
             _LOGGER.warning("*** Error type: " + err.etype)
             _LOGGER.warning("*** Error condition: " + err.condition)
 
-    
     def refresh_statuses(self):
         try:
             self.exc_command('getCleanInfo')
@@ -663,9 +675,19 @@ class VacBot():
             _LOGGER.warning("*** Error type: " + err.etype)
             _LOGGER.warning("*** Error condition: " + err.condition)
 
+    def refresh_liveMap(self):
+        try:
+            self.exc_command('getMajorMap')
+            self.CreatePNGMap()
+        except XMPPError as err:
+            _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
+            _LOGGER.warning("*** Error type: " + err.etype)
+            _LOGGER.warning("*** Error condition: " + err.condition)
+
     def request_all_statuses(self):
         self.refresh_statuses()
         self.refresh_components()
+        self.refresh_liveMap()
 
 	#Common ecovacs commands
     def Clean(self, type='auto'):
@@ -757,24 +779,21 @@ class VacBot():
         imageX = 0
         imageY = 0
 
-        prev = self.mapPieces[0] - 1
-        for mapPiece in self.mapPieces:
-            if mapPiece != self.mapPieces[0]:
-                if mapPiece % 8 != 0:
+        for i in range(64):
+            if i > 0:
+                if i % 8 != 0:
                         imageY += 100
                 else:
                     imageX += 100
                     imageY = 0
 
-            prev = mapPiece
-
-            _LOGGER.debug('PIECE: ' + str(mapPiece) + ' X:' + str(imageX) + ' Y:' + str(imageY))
+            _LOGGER.debug('PIECE: ' + str(i) + ' X:' + str(imageX) + ' Y:' + str(imageY))
 
             for x in range(100):
                 for y in range(100):
-                    if self.buffer[mapPiece][x][y] == 0x01: #floor
+                    if self.buffer[i][x][y] == 0x01: #floor
                         draw.point((imageX+x,imageY+y), fill=(186,218,255))
-                    if self.buffer[mapPiece][x][y] == 0x02: #wall
+                    if self.buffer[i][x][y] == 0x02: #wall
                         draw.point((imageX+x,imageY+y), fill=(78,150,226))
 
         del draw
@@ -798,7 +817,6 @@ class VacBot():
         self.live_map = base64.b64encode(buffered.getvalue())
 
     def UpdateMapBuffer(self, mapPiece, matrix):
-        self.mapPieces.append(mapPiece)
         self.buffer[mapPiece] = matrix
 
 #This is used by EcoVacsIOTMQ for _ctl_to_dict
@@ -1042,6 +1060,8 @@ class EcoVacsIOTMQ(ClientMQTT):
                 jsonstring['event'] = "cached_map"
             elif 'minormap' in eventname:
                 jsonstring['event'] = "minor_map"
+            elif 'majormap' in eventname:
+                jsonstring['event'] = "major_map"
             elif 'mapset' in eventname:
                 jsonstring['event'] = "map_set"
             elif 'mapsubset' in eventname:
