@@ -193,13 +193,15 @@ def run(actions, debug):
                          config['country'], config['continent'], verify_ssl=config['verify_ssl'])
         vacuum = api.devices()[0]
         vacbot = VacBot(api.uid, api.REALM, api.resource, api.user_access_token, vacuum, config['continent'], verify_ssl=config['verify_ssl'])
+        
         vacbot.connect_and_wait_until_ready()
 
         for action in actions:
             click.echo("performing " + str(action.vac_command))
+            vacbot.request_all_statuses()
+            vacbot.CreatePNGMap()
             #vacbot.SetFanSpeed('normal')
-            vacbot.CustomArea('-1008,-2302,250,-3240',1)
-            vacbot.refresh_statuses()
+ 
             #vacbot.request_all_statuses()
             #action.wait.wait(vacbot)
         vacbot.disconnect(wait=True)
@@ -211,7 +213,7 @@ def run(actions, debug):
         _LOGGER.debug("Vacuum Status: {}".format(vacbot.vacuum_status))
         _LOGGER.debug("Fan Speed: {}".format(vacbot.fan_speed))
         _LOGGER.debug("Image Url: {}".format(vacbot.last_clean_image))
-
+        _LOGGER.debug("Live Map: {}".format(vacbot.live_map))
     click.echo("done")
 
 
